@@ -13,15 +13,11 @@ import time
 from bigjob import logger
 import redis
 
-if sys.version_info < (2, 5):
-    sys.path.append(os.path.dirname( os.path.abspath( __file__) ) + "/../ext/uuid-1.30/")
-    sys.stderr.write("Warning: Using unsupported Python version\n")
     
 logging.debug(str(sys.path))
 import uuid
 
 
-
 REDIS_SERVER="localhost"
 REDIS_SERVER_PORT=6379
 REDIS_URL_SCHEME="redis://"
